@@ -2,7 +2,7 @@ package Catmandu::Store::MongoDB::Searcher;
 
 use Catmandu::Sane;
 
-our $VERSION = '0.0805';
+our $VERSION = '0.0806';
 
 use Moo;
 use namespace::clean;
@@ -50,6 +50,12 @@ sub slice {    # TODO constrain total?
 
 sub count {    # TODO constrain on start, total?
     my ($self) = @_;
+    my $query = $self->query;
+    if (!($query && scalar(keys %$query) > 0)
+        && $self->bag->store->estimate_count)
+    {
+        return $self->collection->estimated_document_count();
+    }
     $self->bag->collection->count_documents($self->query,
         $self->bag->_options);
 }
